@@ -1,6 +1,6 @@
 /***
 |''Name''|ImageMacroPlugin|
-|''Version''|0.9.31|
+|''Version''|0.9.4|
 |''Description''|Allows the rendering of svg images in a TiddlyWiki|
 |''Author''|Osmosoft|
 |''License''|[[BSD|http://www.opensource.org/licenses/bsd-license.php]]|
@@ -58,7 +58,9 @@ var macro = config.macros.image = {
 		}
 		var data = new Image();
 		data.onload = function() {
+			// note ie 8 only supports data uris up to 32k so cannot be relied on
 			macro.supportsDataUris = this.width != 1 || this.height != 1 ? false : true;
+			macro.supportsDataUris = macro.ieVersion && macro.ieVersion < 9 ? false : macro.supportsDataUris;
 		};
 		data.onerror = data.onload;
 		data.src = "data:image/gif;base64,R0lGODlhAQABAIAAAAAAAP///ywAAAAAAQABAAACAUwAOw==";
@@ -146,9 +148,9 @@ var macro = config.macros.image = {
 	_renderBinaryImageTiddler: function(place, tiddler, options) {
 		var resourceURI;
 		var fields = tiddler.fields;
-		if(fields["server.type"] == "tiddlyweb") { // construct an accurate url for the resource	
+		if(fields["server.type"] == "tiddlyweb") { // construct an accurate url for the resource
 			resourceURI = "%0/%1/tiddlers/%2".format(config.defaultCustomFields["server.host"],
-				fields["server.workspace"], fields["server.title"]);
+				fields["server.workspace"], encodeURI(fields["server.title"]));
 		} else { // guess the url for the resource
 			resourceURI = tiddler.title;
 		}
@@ -390,13 +392,13 @@ merge(config.macros.view.views, {
 	image: function(value, place, params, wikifier, paramString, tiddler) {
 		// a field can point to another tiddler whereas text is the current tiddler.
 		var title = params[0] == "text" ? tiddler.title : value;
-		paramString = '"%0" %1'.format(title, params.splice(2).join(" "))
-		invokeMacro(place, "image", paramString, null, tiddler);
+		var args = macro.getArguments(paramString, params);
+		macro.renderImage(place, title, args);
 	}
 });
 config.shadowTiddlers.StyleSheetImageMacro = [".wikifiedImage svg, .wikifiedImage .image { width: 80%; }",
 	".svgImageText { background-color:[[ColorPalette::Error]]; color:#ddd; display: inline-block; }",
-	"span.svgImageText { display: inline-block; overflow-hidden; }"
+	"span.svgImageText { display: inline-block; overflow: hidden; }"
 ].join("");
 store.addNotification("StyleSheetImageMacro", refreshStyles);
 
